summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorNeal Gompa (ニール・ゴンパ) <[email protected]>2019-01-08 12:23:05 -0500
committerBrian Behlendorf <[email protected]>2019-01-08 09:23:05 -0800
commit4efb48eecb43717f70817bfb152bf86f7ed28b5b (patch)
tree5bcbcc41d7868045a7d5e6193be5e665b35e7c1b /scripts
parent22448f08942457ab34579cb7d7edbcf635fa25a6 (diff)
Bump commit subject length to 72 characters
There's not really a reason to keep the subject length so short, since the reason to make it this short was for making nice renders of a summary list of the git log. With 72 characters, this still works out fine, so let's just raise it to that so that it's easier to give slightly more descriptive change summaries. Reviewed by: Matt Ahrens <[email protected]> Reviewed-by: Tony Hutter <[email protected]> Reviewed-by: Brian Behlendorf <[email protected]> Signed-off-by: Neal Gompa <[email protected]> Closes #8250
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/commitcheck.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/commitcheck.sh b/scripts/commitcheck.sh
index f377bb912..2954b0fd7 100755
--- a/scripts/commitcheck.sh
+++ b/scripts/commitcheck.sh
@@ -69,10 +69,10 @@ function new_change_commit()
{
error=0
- # subject is not longer than 50 characters
- long_subject=$(git log -n 1 --pretty=%s "$REF" | grep -E -m 1 '.{51}')
+ # subject is not longer than 72 characters
+ long_subject=$(git log -n 1 --pretty=%s "$REF" | grep -E -m 1 '.{73}')
if [ -n "$long_subject" ]; then
- echo "error: commit subject over 50 characters"
+ echo "error: commit subject over 72 characters"
error=1
fi